[lld-macho] Parallel input section priorities for -order_file (#241470) buildInputSectionPriorities() used to look up every symbol in `priorities`, which does a bunch of work (hash a symbol, do some string manipulation). Instead, call getSymbolPriority in parallel over object files, and then serially merge the results. (This works because std::min() is associative.) Takes a Chromium Framework link on my machine from 4.191 s ± 0.020 s to 3.970 s ± 0.045 s. Chromium uses an order file with just a few entries. I also checked with a synthetic order file that lists all symbols. There, this phase goes from 781 ms to 357 ms, so it's still faster (the relative speedup is just smaller). Contributes to #222068, depends on #241367. No behavior change. GitOrigin-RevId: 82c882f2469f5ca80fa7bd75a42ec9a45d7774f4
This directory and its subdirectories contain source code for the LLVM Linker, a modular cross platform linker which is built as part of the LLVM compiler infrastructure project.
lld is open source software. You may freely distribute it under the terms of the license agreement found in LICENSE.txt.
In order to make sure various developers can evaluate patches over the same tests, we create a collection of self contained programs.
It is hosted at https://s3-us-west-2.amazonaws.com/linker-tests/lld-speed-test.tar.xz
The current sha256 is 10eec685463d5a8bbf08d77f4ca96282161d396c65bd97dc99dbde644a31610f.